@@ -1,8 +1,6 @@
-# -----------------------------------------------------------------------------
-# Description:    General utilities.
-# Repository:     https://gitlab.com/quantify-os/quantify-core
-# Copyright (C) Qblox BV & Orange Quantum Systems Holding BV (2020-2021)
-# -----------------------------------------------------------------------------
+# Repository: https://gitlab.com/quantify-os/quantify-core
+# Licensed according to the LICENCE file on the master branch
+"""General utilities."""
 import importlib
 import copy
 import json
